@@ -25,7 +25,15 @@ common_ignore_deps = ['xbmc.metadata.scraper.albums', 'xbmc.metadata.scraper.mov
                       'kodi.audioencoder', 'kodi.audiodecoder', 'xbmc.service', 'kodi.resource.images',
                       'kodi.resource.language', 'kodi.resource.uisounds', 'kodi.resource.games',
                       'kodi.resource.font', 'kodi.inputstream', 'kodi.vfs', 'kodi.imagedecoder', 'xbmc.addon',
-                      'xbmc.gui', 'xbmc.json', 'xbmc.metadata', 'xbmc.python', 'script.module.pil']
+                      'xbmc.gui', 'xbmc.json', 'xbmc.metadata', 'xbmc.python', 'script.module.pil',
+                      'kodi.binary.global.main', 'kodi.binary.global.audioengine', 'kodi.binary.global.filesystem',
+                      'kodi.binary.global.general', 'kodi.binary.global.gui', 'kodi.binary.global.main',
+                      'kodi.binary.global.network', 'kodi.binary.global.tools', 'kodi.binary.instance.audiodecoder',
+                      'kodi.binary.instance.audioencoder', 'kodi.binary.instance.game',
+                      'kodi.binary.instance.imagedecoder', 'kodi.binary.instance.inputstream',
+                      'kodi.binary.instance.peripheral', 'kodi.binary.instance.pvr', 'kodi.binary.instance.screensaver',
+                      'kodi.binary.instance.vfs', 'kodi.binary.instance.videocodec',
+                      'kodi.binary.instance.visualization']
 
 extensions = {"kodi.gameclient": "kodi.binary.instance.game",
               "xbmc.gui.skin": "xbmc.gui",
@@ -56,29 +64,73 @@ VERSION_ATTRB = {
         'krypton': {'min_compatible': '2.1.0', 'advised': '2.25.0'},
         'leia': {'min_compatible': '2.1.0', 'advised': '2.26.0'},
         'matrix': {'min_compatible': '3.0.0', 'advised': '3.0.0'}
-    }
+    },
+    'xbmc.gui': {
+        'gotham': {'min_compatible': '5.0.0', 'advised': '5.0.0'},
+        'helix': {'min_compatible': '5.3.0', 'advised': '5.3.0'},
+        'isengard': {'min_compatible': '5.3.0', 'advised': '5.9.0'},
+        'jarvis': {'min_compatible': '5.10.0', 'advised': '5.10.0'},
+        'krypton': {'min_compatible': '5.12.0', 'advised': '5.12.0'},
+        'leia': {'min_compatible': '5.14.0', 'advised': '5.14.0'},
+        'matrix': {'min_compatible': '5.14.0', 'advised': '5.15.0'}
+    },
+    'xbmc.json': {
+        'gotham': {'min_compatible': '6.0.0', 'advised': '5.0.0'},
+        'helix': {'min_compatible': '6.0.0', 'advised': '6.20.0'},
+        'isengard': {'min_compatible': '6.0.0', 'advised': '6.25.1'},
+        'jarvis': {'min_compatible': '6.0.0', 'advised': '6.32.4'},
+        'krypton': {'min_compatible': '6.0.0', 'advised': '7.0.0'},
+        'leia': {'min_compatible': '6.0.0', 'advised': '9.7.2'},
+        'matrix': {'min_compatible': '6.0.0', 'advised': '11.2.0'}
+    },
+    'xbmc.addon': {
+        'gotham': {'min_compatible': '12.0.0', 'advised': '13.0.0'},
+        'helix': {'min_compatible': '12.0.0', 'advised': '14.0.0'},
+        'isengard': {'min_compatible': '12.0.0', 'advised': '15.0.0'},
+        'jarvis': {'min_compatible': '12.0.0', 'advised': '16.0.0'},
+        'krypton': {'min_compatible': '12.0.0', 'advised': '17.0.0'},
+        'leia': {'min_compatible': '12.0.0', 'advised': '17.9.910'},
+        'matrix': {'min_compatible': '12.0.0', 'advised': '18.9.701'}
+    },
+    'xbmc.metadata': {
+        'gotham': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'helix': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'isengard': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'jarvis': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'krypton': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'leia': {'min_compatible': '1.0', 'advised': '2.1.0'},
+        'matrix': {'min_compatible': '1.0', 'advised': '2.1.0'}
+    },
 }
 
 LOGGER = logging.getLogger(__name__)
 
 
-def check_addon_dependencies(report: Report, repo_addons: dict, parsed_xml, branch_name: str):
+def check_addon_dependencies(report: Report, repo_addons: dict, parsed_xml, args):
     """Check for any new dependencies in addon.xml file and reports them
         :parsed_xml: parsed addon.xml file
         :repo_addons: dictionary having all the addon list of a particular
                         version of kodi
-        :branch_name: name of the kodi branch/version
+        :args: the args object passed to addon-checker
     """
 
     addon = Addon(parsed_xml)
-    ignore = _get_ignore_list(KodiVersion(branch_name))
+    ignore = _get_ignore_list(KodiVersion(args.branch))
+    pr = bool(args.PR)
 
     for dependency in addon.dependencies:
         if dependency.id in ignore and not dependency.optional:
             pass
 
         elif dependency.id not in repo_addons:
-            report.add(Record(INFORMATION if dependency.optional else PROBLEM,
+            if dependency.optional:
+                record_level = INFORMATION
+            elif not pr:
+                record_level = WARNING
+            else:
+                record_level = PROBLEM
+
+            report.add(Record(record_level,
                               "{} dependency {} is not available in current repository"
                               .format("Optional" if dependency.optional else "Required", dependency.id)))
 
@@ -96,16 +148,16 @@ def check_addon_dependencies(report: Report, repo_addons: dict, parsed_xml, bran
 
         if dependency.id in VERSION_ATTRB:
             try:
-                version_info = VERSION_ATTRB[dependency.id][branch_name]
+                version_info = VERSION_ATTRB[dependency.id][args.branch]
                 if AddonVersion(version_info["min_compatible"]) > dependency.version:
                     report.add(Record(PROBLEM, "For {}, {} version must be higher than {}. Advised {}."
-                                      .format(branch_name, dependency.id,
+                                      .format(args.branch, dependency.id,
                                               version_info["min_compatible"], version_info["advised"])))
                     continue
 
                 if AddonVersion(version_info["advised"]) != dependency.version:
                     report.add(Record(WARNING, "For {} it is advised to set {} version to {}"
-                                      .format(branch_name, dependency.id, version_info["advised"])))
+                                      .format(args.branch, dependency.id, version_info["advised"])))
 
             except KeyError:
                 LOGGER.warning("Misconfiguration in VERSION_ATTRB of check_dependencies")
@@ -161,7 +213,7 @@ def _get_ignore_list(kodi_version: KodiVersion):
        on the branch name
     """
 
-    if kodi_version == KodiVersion("leia"):
+    if kodi_version >= KodiVersion("leia"):
         common_ignore_deps.extend(["script.module.pycryptodome"])
 
     if kodi_version == KodiVersion("krypton"):
