@@ -1,4 +1,12 @@
-from kodi_addon_checker.record import INFORMATION, WARNING, PROBLEM
+"""
+    Copyright (C) 2017-2018 Team Kodi
+    This file is part of Kodi - kodi.tv
+
+    SPDX-License-Identifier: GPL-3.0-only
+    See LICENSES/README.md for more information.
+"""
+
+from kodi_addon_checker.record import INFORMATION, PROBLEM, WARNING
 from kodi_addon_checker.report import Record
 from kodi_addon_checker.reporter import Reporter, reporter
 
@@ -15,9 +23,10 @@ def colorPrint(string, color):
 
 @reporter(name="console", enabled=True)
 class ConsoleReporter(Reporter):
-
+    """Present Report on the console
+    """
     def report(self, report):
-        if type(report) is Record:
+        if isinstance(report, Record):
             if report.log_level == INFORMATION:
                 colorPrint(report, "34")
             elif report.log_level == WARNING:
